========
Moccasin
========

.. toctree::
    :maxdepth: 3

    Overview <index.rst>

.. toctree::
    :caption: Getting Started
    :maxdepth: 3

    installing_moccasin.rst
    quickstart.rst

.. toctree::
    :caption: Core Concepts
    :maxdepth: 3

    moccasin.toml <core_concepts/moccasin_toml.rst>
    core_concepts/project.rst
    core_concepts/networks.rst
    core_concepts/dependencies.rst 
    core_concepts/named_contracts.rst
    core_concepts/testing.rst
    Wallet <core_concepts/wallet.rst>
    Scripting (run) <core_concepts/script.rst>
    core_concepts/deployments.rst

.. toctree::
    :caption: How-to Guides
    :maxdepth: 3

    Contract Verification <how-tos/verify_contracts.rst>
    

.. toctree::
    :caption: Tutorials
    :maxdepth: 3

    ZKsync <tutorials/zksync-getting-started.rst>

.. toctree::
    :caption: Reference
    :maxdepth: 3

    cli_commands.rst
    class_reference.rst
    all_moccasin_toml_parameters.rst
    explorer_network_defaults.rst
    common_errors.rst

